# #Script en R 
# title: "Efecto del tratado MERCOSUR-UE en el sector agrícola"
# subtitle: "Ejemplo Trabajo, Integración Económica, 4º ECO, UVEG"
# author: "Jordi Paniagua"
# # email: jordi.paniagua@uv.es
# #institute: [uv, nd]
# 25.01.2025

#### Código para descargar datos de comercio y generar una figura

# Cargar librerías necesarias
# Instalar y cargar el paquete
#install.packages("comtradr")
library(comtradr)
library(ggplot2)
library(dplyr)
library(tidyr)
library(haven)


# Configuración inicial
start_year <- 2010
end_year <- 2020
reporter <- c("ARG", "BRA", "PRY", "URY")  # Ejemplo con un país del MERCOSUR
partner <-  c("AUT", "BEL", "DEU", "DNK", "FIN", "FRA", "GBR", "GRC", "IRL", "ITA",
              "ESP", "LUX", "NLD", "PRT", "SWE", "CZE", "HUN", "POL", "SVK", "SVN",
              "MLT", "CYP", "EST", "LTU", "LVA", "BGR", "ROU", "HRV") # Unión Europea

# Códigos HS para productos agrícolas
agriculture_hs_codes <- c(
  "01", "02", "03", "04", "05", "06", "07", "08", "09", "10",
  "11", "12", "13", "14", "15", "16", "17", "18", "19", "20",
  "21", "22", "23", "24"
)

#Podemos ver los códigos
#ct_get_ref_table('HS')

#Este token se obtiene dándose de alta como usuario en Comtrade
set_primary_comtrade_key(key = "783d13af6edf45aaa53ea60a09972f92")

# Obtener datos de comercio agrícola
data_comtrade <- ct_get_data(
  reporter = reporter,     # Un solo país como reportero
  partner = partner,       # Un solo socio comercial
  start_date = start_year,
  end_date = end_year,
  commodity_classification = "HS",
  commodity_code =agriculture_hs_codes,
  verbose = TRUE
)

#lo guardamos 
write_dta(data_comtrade, "data_comtrade.dta")

#cargamos (API de comtrade puede tardar)
data_comtrade <- read_dta("data_comtrade.dta")

data_comtrade <- as.data.frame(data_comtrade)

# Verificar los datos descargados
#head(data_comtrade)

#Nos quedamoscon las exportaciones e importaciones
data_comtrade_exports <- data_comtrade %>%
  filter(flow_desc=="Export" |  flow_desc=="Import")
# Verificar
#table(data_comtrade_exports$flow_desc)



#Colapsamos
data_comtrade_exports <- data_comtrade_exports %>%
  group_by(ref_year, flow_desc) %>%
  summarise(across(c( primary_value  ), ~ sum(.x, na.rm = TRUE), .names = "total_{.col}"))

#valores en millones
data_comtrade_exports <- data_comtrade_exports %>%
  mutate(total_primary_value=total_primary_value/1000000)


# Procesar y graficar

msur_ue_plot <- ggplot(data_comtrade_exports, aes(x = ref_year, y = total_primary_value, color = flow_desc, group = flow_desc)) +
  geom_line(size = 0.5) + geom_line(size = 0.5) +
  labs(
#    title = paste("Comercio entre MERCORSUR y la UE"),
    x = "Año",
    y = "Valor del comercio (millones USD)",
    caption="Fuente datos: COMTRADE"
  ) +
  theme_minimal() +
  theme(
    plot.title = element_text(hjust = 0.5, size = 16, face = "bold"),
    axis.text = element_text(size = 12),
    axis.title = element_text(size = 14)
  )

msur_ue_plot

# Guardar el mapa en un archivo PDF
ggsave("MERCOSUR_UE_Trade.pdf", plot = msur_ue_plot, width = 10, height = 6)





# #### Código para descargar datos de comercio y generar una figura
# 

# Cargar los paquetes necesarios para la regresión 
library(penppml)
library(haven)
library(dplyr)
library(tidyr)
library(xtable)

library(huxtable)
library(broom)


# Cargar los datos
data <- read_dta("fin_ADB_2007_2011_2017.dta")

# # Filtrar por sector agricultura
data <- filter(data, sector == 1)

# Filtrar por año 2017
data <- filter(data, y == 2017)

# # Colapsar los datos sumando 'trade' por 'iso3_o', 'iso3_d', 'y' y 'sector'
collapsed_data <- data %>%
  group_by(iso3_o, iso3_d, y, sector) %>%
  summarise(trade = sum(trade, na.rm = TRUE))

# # Colapsar los datos sumando 'trade' por 'iso3_o', 'iso3_d', 'y' y 'sector'
# # suma todos los sectores
# collapsed_data <- data %>%
#   group_by(iso3_o, iso3_d, y) %>%
#   summarise(trade = sum(trade, na.rm = TRUE))
# 
# #para todos los sectores
# collapsed_data <- collapsed_data %>%
#   mutate(sector = 0
#          )

# # Mantener solo las columnas necesarias
collapsed_data <- collapsed_data %>%
  select(iso3_o, iso3_d, y, trade, sector)

# Crear las nuevas variables
collapsed_data <- collapsed_data %>%
  mutate(exporter = iso3_o,
         importer = iso3_d,
         exporter_iso3 = iso3_o,
         importer_iso3 = iso3_d,
         year = y)

# Cargar los datos adicionales para el merge
grav_data_clean <- read_dta("grav_data_clean.dta")

# Realizar el left join
merged_data <- left_join(collapsed_data, grav_data_clean, 
                         by = c("exporter_iso3" = "exporter_iso3", 
                                "importer_iso3" = "importer_iso3", 
                                "year" = "year"), unmatched = "drop")
# Definir las variables
xvars <- c("EU", "WTO", "SANCT", "RTA", "FTA")

# Reemplazar NA por 0 en cada variable
for (zz in xvars) {
  merged_data[[zz]] <- ifelse(is.na(merged_data[[zz]]), 0, merged_data[[zz]])
}

# Eliminar filas duplicadas basadas en iso3_o, iso3_d, y, y sector
merged_data <- merged_data %>%
  distinct(iso3_o, iso3_d, y, sector, .keep_all = TRUE)

#Cargar los datos de DTA 2.0
fin_DTA20 <- read_dta("fin_DTA20.dta")

# Realizar el merge 1:1 con DTA 2.0
merged_data <- left_join(merged_data, fin_DTA20, 
                         by = c("iso3_o", "iso3_d", "y"), unmatched = "drop")

# # Cargar los datos de distancia bilateral
# bilateraldistance <- read_dta("bilateraldistance.dta")
# 
# # Realizar el merge n:1 con distancia bilateral
# merged_data <- left_join(merged_data, bilateraldistance, 
#                          by = c("iso3_o", "iso3_d"))
# 
# # Mantener solo las filas donde hay match (NA en las columnas del segundo dataset)
# merged_data <- merged_data %>%
#   filter(!is.na(distw_arithmetic))



# Cargar los datos de distancia bilateral
grav_data_other <- read_dta("grav_data_other.dta")

# Realizar el merge n:1 con distancia bilateral
merged_data <- left_join(merged_data, grav_data_other, 
                         by = c("iso3_o", "iso3_d"), unmatched = "drop")
# Mantener solo las filas donde hay match (NA en las columnas del segundo dataset)
merged_data <- merged_data %>%
  filter(!is.na(distw))

#summary(merged_data$colony)

# Eliminar las columnas no deseadas
# merged_data <- merged_data %>%
#   select(-dist, -distcap) %>%
# rename(distw = distw_arithmetic)

# Identificar y listar los duplicados basados en iso3_o, iso3_d, y, y sector
duplicates <- merged_data %>%
  group_by(iso3_o, iso3_d, y, sector) %>%
  filter(n() > 1) %>%
  ungroup()

# Mostrar los duplicados
print(duplicates)

# Eliminar filas duplicadas basadas en iso3_o, iso3_d, y, y sector
merged_data <- merged_data %>%
  distinct(iso3_o, iso3_d, y, sector, .keep_all = TRUE)

# Crear las variables eu_o y eu_d y asignarles el valor 0
merged_data <- merged_data %>%
  mutate(
    eu_o = ifelse(exporter %in% c("AUT", "BEL", "DEU", "DNK", "FIN", "FRA", "GBR", "GRC", "IRL", "ITA", 
                                  "ESP", "LUX", "NLD", "PRT", "SWE", "CZE", "HUN", "POL", "SVK", "SVN", 
                                  "MLT", "CYP", "EST", "LTU", "LVA", "BGR", "ROU", "HRV"), 1, 0),  # Asignar 1 si el exporter está en la UE
    eu_d = ifelse(importer %in% c("AUT", "BEL", "DEU", "DNK", "FIN", "FRA", "GBR", "GRC", "IRL", "ITA", 
                                  "ESP", "LUX", "NLD", "PRT", "SWE", "CZE", "HUN", "POL", "SVK", "SVN", 
                                  "MLT", "CYP", "EST", "LTU", "LVA", "BGR", "ROU", "HRV"), 1, 0)   # Asignar 1 si el importer está en la UE
  )

#summary(merged_data$eu_o)
#summary(merged_data$eu_d)

# Crear las variables ot, dt y od agrupando por iso3_o, iso3_d y y
merged_data <- merged_data %>%
  group_by(iso3_o, y) %>%
  mutate(ot = cur_group_id()) %>%
  ungroup() %>%
  group_by(iso3_d, y) %>%
  mutate(dt = cur_group_id()) %>%
  ungroup() %>%
  group_by(iso3_o, iso3_d) %>%
  mutate(od = cur_group_id()) %>%
  ungroup()

# Crear la variable BORDER y asignar el valor 0
merged_data <- merged_data %>%
  mutate(BORDER = 0)

# Reemplazar BORDER con 1 si exporter es diferente de importer
merged_data <- merged_data %>%
  mutate(BORDER = ifelse(exporter != importer, 1, BORDER))


# Crear las variables para identificar países de la UE y Mercosur
merged_data <- merged_data %>%
  mutate(EU_e = eu_o,
         EU_i = eu_d,
         EU_e = ifelse(exporter == "GBR", 0, EU_e),
         EU_i = ifelse(importer == "GBR", 0, EU_i),
         MERCOSUR_e = ifelse(exporter %in% c("ARG", "BRA", "PRY", "URY"), 1, 0),
         MERCOSUR_i = ifelse(importer %in% c("ARG", "BRA", "PRY", "URY"), 1, 0))

# Crear las variables para identificar EU-MERCOSUR
merged_data <- merged_data %>%
  mutate(EU_MERC = ifelse((MERCOSUR_e | MERCOSUR_i) & (EU_e | EU_i), 1, 0),
         EU_MERC_dir = ifelse(EU_MERC == 1 & EU_e == 1 & EU_i == 0, 1, 0),
         MERC_EU_dir = ifelse(EU_MERC == 1 & MERCOSUR_e == 1 & MERCOSUR_i == 0, 1, 0))

#summary(merged_data$North_exp)

# Crear las variables North_exp y North_imp
north_countries <- c("AUS", "LUX", "KOR", "AUT", "CAN", "CYP", "DNK", "FIN", "FRA", 
                     "DEU", "GRC", "ISL", "IRL", "ISR", "ITA", "JPN", "BEL", "NLD", 
                     "NZL", "NOR", "PRT", "ESP", "SWE", "CHE", "GBR", "USA")

merged_data <- merged_data %>%
  mutate(North_exp = ifelse(exporter %in% north_countries, 1, 0),
         North_imp = ifelse(importer %in% north_countries, 1, 0))

# Crear la variable TA_like_EUMERC
merged_data <- merged_data %>%
  mutate(TA_like_EUMERC = ifelse(wto_plus_ftaindustrial == 1 & wto_plus_ftaagriculture == 1 & 
                                   wto_plus_customs == 1 & wto_plus_exporttaxes == 1 & 
                                   wto_plus_sps == 1 & wto_plus_tbt == 1 & wto_plus_ste == 1 & 
                                   wto_plus_publicprocurement == 1 & wto_plus_gats == 1 & 
                                   wto_plus_trips == 1 & wto_x_ipr == 1 & 
                                   wto_x_competitionpolicy == 1 & wto_x_investment == 1 & 
                                   wto_x_labourmarketregulation == 1 & wto_x_environmentallaws == 1 & 
                                   wto_x_movementofcapital == 1, 1, 0))

# Crear la variable TA_rest_HorDepthDB
merged_data <- merged_data %>%
  mutate(TA_rest_HorDepthDB = wto_plus_ftaindustrial - TA_like_EUMERC,
         TA_rest_HorDepthDB = ifelse(is.na(TA_rest_HorDepthDB), 0, TA_rest_HorDepthDB))

# Crear las variables direccionales
merged_data <- merged_data %>%
  mutate(TA_like_EUMERC_N_to_S = ifelse(TA_like_EUMERC == 1 & North_exp == 1 & North_imp == 0, 1, 0),
         TA_like_EUMERC_S_to_N = ifelse(TA_like_EUMERC == 1 & North_exp == 0 & North_imp == 1, 1, 0),
         TA_like_EUMERC_rest = TA_like_EUMERC - TA_like_EUMERC_N_to_S - TA_like_EUMERC_S_to_N)

# Crear la variable lnDIST a partir de lndistw
merged_data <- merged_data %>%
  mutate(lndistw = log(distw))

subset_data <- merged_data %>%
  select(trade, TA_like_EUMERC_N_to_S, TA_like_EUMERC_S_to_N, TA_like_EUMERC_rest, 
         TA_rest_HorDepthDB, BORDER, lndistw, ot, dt, EU_MERC, EU_MERC_dir, MERC_EU_dir, exporter, importer,
         colony, comcur, comrelig, comcol, contig, comlang_off, gdp_o, gdp_d, pop_o, pop_d ,distw,
         WTO, SANCT, RTA, FTA, TA_like_EUMERC)

# subset_data <- subset_data %>% rename(TAlikeEUMERCNtoS=TA_like_EUMERC_N_to_S )
# subset_data <- subset_data %>% rename(TAlikeEUMERCStoN=TA_like_EUMERC_S_to_N )
# subset_data <- subset_data %>% rename(TAlikeEUMERCrest=TA_like_EUMERC_rest )
# subset_data <- subset_data %>% rename(TArestHorDepthDB=TA_rest_HorDepthDB )

subset_data <- subset_data %>%
  mutate(
    TA_like_EUMERC_N_to_S = ifelse(is.na(TA_like_EUMERC_N_to_S), 0, TA_like_EUMERC_N_to_S),
    TA_like_EUMERC_S_to_N = ifelse(is.na(TA_like_EUMERC_S_to_N), 0, TA_like_EUMERC_S_to_N),
    TA_like_EUMERC_rest = ifelse(is.na(TA_like_EUMERC_rest), 0, TA_like_EUMERC_rest),
    TA_rest_HorDepthDB = ifelse(is.na(TA_rest_HorDepthDB), 0, TA_rest_HorDepthDB)
  )

subset_data <- subset_data %>%
  mutate(
    WTO = ifelse(is.na(WTO), 0, WTO),
    RTA = ifelse(is.na(RTA), 0, RTA),
    FTA = ifelse(is.na(SANCT), 0, FTA),
    SANCT = ifelse(is.na(SANCT), 0, SANCT),
    TA_like_EUMERC = ifelse(is.na(TA_like_EUMERC), 0, TA_like_EUMERC)
  )

subset_data <- subset_data %>%
  mutate(
    RTA = ifelse(TA_like_EUMERC==1, 0, RTA)
  )

subset_data <- subset_data %>%
  mutate(
    colony = ifelse(is.na(colony), 0, colony),
    contig = ifelse(is.na(contig), 0, contig),
    FTA = ifelse(is.na(comlang_off), 0, comlang_off)
  )

# subset_data$trade <- as.numeric(format(subset_data$trade, scientific = FALSE))
# options(scipen = 999)
# head(subset_data$trade)
subset_data <- as.data.frame(subset_data)

#VAmos con las regreiones
#Reg 1: Factores físicos /coste
reg1 <- hdfeppml(data = subset_data,
                 dep = "trade",
                 indep = c("BORDER", "lndistw", "contig"),
                 fixed = list(c("ot"), c("dt")))

#Reg2: Añadimos factores culturales
reg2 <- hdfeppml(data = subset_data,
                 dep = "trade",
                 indep = c("BORDER", "lndistw", 
                           "colony", "contig", "comlang_off"),
                 fixed = list(c("ot"), c("dt")))


#Reg3: Añadimos factores Política comercial
reg3 <- hdfeppml(data = subset_data,
                 dep = "trade",
                 indep = c("BORDER", "lndistw", 
                           "colony", "contig", "comlang_off", "WTO", "TA_like_EUMERC"),
                 fixed = list(c("ot"), c("dt")))

#Para tener los resultados en tablas standard
# Método tidy() para la clase ficticia (toas las regresiones)
tidy.fake_model <- function(x, ...) {
  data.frame(
    term = names(x$coefficients),
    estimate = x$coefficients,
    std.error = x$std.error,
    stars = x$stars
  )
}

glance.fake_model <- function(x, ...) {
  data.frame(
    nobs = x$n_obs,
    r.squared = x$r_squared
  )
}

# Inicializar listas para almacenar resultados y modelos
results_list <- list()
fake_models <- list()

# Crear un vector con los nombres de los modelos (reg1, reg2, reg3)
model_names <- c("reg1", "reg2", "reg3")

# Loop para procesar cada modelo
for (i in seq_along(model_names)) {
  model <- get(model_names[i]) # Obtener el modelo dinámicamente
  
  # Crear el data.frame de resultados
  results <- data.frame(
    prov = rownames(model$coefficients),
    b = model$coefficients,
    se = 0,
    p = 0,
    n = nrow(model$residuals),
    rsq = 0
  )
  
  # Asignar errores estándar donde corresponda
  results$se[!is.na(model$coefficients)] <- model$se
  
  # Calcular y_hat y R^2
  y_hat <- model$mu + model$residuals
  rsq <- cor(model$mu, y_hat)^2
  
  # Calcular p-valores
  results$t <- results$b / results$se
  results$p <- 2 * (1 - pt(abs(results$t), df = nrow(model$residuals) - 1))
  
  # Añadir asteriscos según significancia
  results$stars <- cut(
    results$p,
    breaks = c(-Inf, 0.01, 0.05, 0.1, Inf),
    labels = c("***", "**", "*", ""),
    right = FALSE
  )
  
  # Guardar los resultados en la lista
  results_list[[i]] <- results
  
  # Crear un modelo ficticio compatible con huxreg
  fake_model <- list(
    coefficients = setNames(results$b, results$prov),
    std.error = setNames(results$se, results$prov),
    stars = setNames(results$stars, results$prov),
    n_obs = unique(results$n),
    r_squared = rsq
  )
  
  # Asignar clase y guardar el modelo ficticio
  class(fake_model) <- "fake_model"
  fake_models[[i]] <- tidy_override(fake_model, glance = list(nobs = unique(results$n), r.squared = rsq))
}

# Acceder a los resultados y modelos por índice
results1 <- results_list[[1]]
results2 <- results_list[[2]]
results3 <- results_list[[3]]

fake_model1 <- fake_models[[1]]
fake_model2 <- fake_models[[2]]
fake_model3 <- fake_models[[3]]

# 
# 
# #Regresión 1 sin loop
# 
# results1 <- data.frame(prov = rownames(reg1$coefficients), 
#                        b = reg1$coefficients, 
#                        se = 0, 
#                        p=0,
#                        n= nrow(reg1$residuals),
#                        rsq=0)
# results1$se[!is.na(reg2$coefficients)] <- reg1$se
# results2
# 
# 
# y_hat<-reg1$mu +reg1$residuals
# rsq2<-cor(reg1$mu,y_hat )^2
# 
# # Reemplazar "_" por "\_" en los nombres de las variables
# #results$prov <- gsub("_", "", results$prov, fixed = TRUE)
# 
# # Calcular p-valores
# results1$t <- results1$b / results1$se
# results1$p <- 2 * (1 - pt(abs(results1$t), df = nrow(results1) - 1))
# 
# 
# # Añadir asteriscos según significancia
# results1$stars <- cut(
#   results2$p,
#   breaks = c(-Inf, 0.01, 0.05, 0.1, Inf),
#   labels = c("***", "**", "*", ""),
#   right = FALSE
# )
# 
# results1
# 
# # Crear un modelo ficticio compatible con huxreg
# fake_model1 <- list(
#   coefficients = setNames(results1$b, results1$prov),
#   std.error = setNames(results1$se, results1$prov),
#   stars = setNames(results1$stars, results1$prov),
#   n_obs =unique(results1$n),
#   r_squared = rsq2
# )
# 
#  
# # Crear una clase ficticia para que sea compatible con tidy()
# class(fake_model1) <- "fake_model"
# 
# 
# #Añadir el número de observaciones
# #con glance = list(r.squared = 0.99)) podemos añadir también el R2
# 
# # fake_model1 <-tidy_override(fake_model1, glance=list(nobs=unique(results$n), r.squared =rsq1)) 
# fake_model1 <-tidy_override(fake_model1, glance=list(nobs=unique(results1$n), r.squared =rsq2)) 

# Reportar los resultados con huxreg (con asteriscos y errores estándar)
reg_table <-huxreg(
  fake_model1, fake_model2, fake_model3,
  error_format = "({std.error}){stars}",
  stars = c(`***` = 0.01, `**` = 0.05, `*` = 0.1),
  statistics = c(N = "nobs", R2 = "r.squared")
)

# Añadir título y etiqueta
caption(reg_table) <- "Resultados: Equilibrio parcial"
label(reg_table) <- "tab:resultados"

writeLines(to_latex(reg_table), "reg_table.tex")


#Equilibrio General y Gráficos

# Cargar librerías necesarias

library(devtools)
#Instalar si es necesario
# devtools::install_github("https://github.com/VKudlay/GEGravity/blob/master/R/ge_gravity.R") 
# devtools::install_github("https://github.com/VKudlay/GEGravity/blob/master/R/data.R") 
# devtools::install_github("https://github.com/amrei-stammann/alpaca") 

library(GEGravity)

#DEfinimoa el contrafactual, aumentamos el coeficiente de MERCOSUR-EU como el resto de tratados

subset_data$MERCOSUR <-  subset_data$EU_MERC*results3$b[7]  # Column for the partial effect of EU membership for new EU pairs

subset_data <- subset_data %>%
  mutate(
    MERCOSUR = ifelse(is.na(MERCOSUR), 0, MERCOSUR)
  )

#summary(subset_data$MERCOSUR)

#Equilibrio General
w_mult_mercosur_sim <- ge_gravity(
  exp_id = subset_data$exporter,     # Origin country associated with each observation
  imp_id = subset_data$importer,     # Destination country associated with each observation
  flows  = subset_data$trade,       # Observed trade flows for the baseline year
  beta   = subset_data$MERCOSUR,   # "Partial" trade change; coefficient from gravity estimation
  theta  = 4,                # Trade elasticity
  mult   = TRUE,             # Assume national expenditure is fixed multiple of nat. output
  data   = subset_data
)

#Colapsamos por exportador
collapsed_w_mult_mercosur_sim <- w_mult_mercosur_sim %>%
  group_by(exporter) %>%
  summarise(across(c( welfare, real_wage, nom_wage, price_index  ), ~ mean(.x, na.rm = TRUE)))

# head(collapsed_w_mult_mercosur_sim)
# 
# print(collapsed_w_mult_mercosur_sim, n = 60) 

# Crear las variables para identificar países de la UE y Mercosur
collapsed_w_mult_mercosur_sim <- collapsed_w_mult_mercosur_sim %>%
  mutate(MERCOSU = ifelse(exporter %in% c("ARG", "BRA", "PRY", "URY"), 1, 0),
         EU = ifelse(exporter %in% c("AUT", "BEL", "DEU", "DNK", "FIN", "FRA", "GBR", "GRC", "IRL", "ITA", 
                                     "ESP", "LUX", "NLD", "PRT", "SWE", "CZE", "HUN", "POL", "SVK", "SVN", 
                                     "MLT", "CYP", "EST", "LTU", "LVA", "BGR", "ROU", "HRV"), 1, 0),  # Asignar 1 si el exporter está en la UE
  )

# head(collapsed_w_mult_mercosur_sim)

collapsed_welf<- collapsed_w_mult_mercosur_sim %>%
  group_by(MERCOSU, EU) %>%
  summarise(across(c(real_wage, nom_wage , price_index   ), 
                   ~ mean(.x, na.rm = TRUE, , digits = 4), .names = "mean_{.col}"))

#Mostar 4 decimales
# head(as.data.frame(lapply(collapsed_welf, function(x) {
#   if (is.numeric(x)) format(x, digits = 4, nsmall = 4) else x
# })))

# head(collapsed_w_mult_mercosur_sim)

#En porcentajes
collapsed_welf <- collapsed_welf %>%
  mutate(mean_real_wage=(mean_real_wage-1)*100) %>%
  mutate(mean_nom_wage=(mean_nom_wage-1)*100) %>%
  mutate(mean_price_index=(mean_price_index-1)*100)

colnames(collapsed_welf) <- c("MERCOSUR", "EU", "Salario Real", "Salario Nominal", "Precios")




collapsed_welf_hux <-huxtable(
  collapsed_welf
)
number_format(collapsed_welf_hux)<- "%.5g"

#Vamos a crear una tabla
# Añadir título y etiqueta
caption(collapsed_welf_hux) <- "Resultados: Equilibrio General (porcentajes)"
label(collapsed_welf_hux) <- "tab:gegravity"
writeLines(to_latex(collapsed_welf_hux), "collapsed_welf.tex")

#ahora vamos con el mapa
collapsed_w_mult_mercosur_sim <- collapsed_w_mult_mercosur_sim %>%
  mutate(welfare=(real_wage-1)*100
  )

####Gráficos
# install.packages("ggplot2")
# install.packages("rnaturalearth")
# install.packages("rnaturalearthdata")

library(ggplot2)
library(dplyr)
library(rnaturalearth)
library(rnaturalearthdata)

# Cargar shapefile mundial
world <- ne_countries(scale = "medium", returnclass = "sf")

# Filtrar para eliminar la Antártida
world <- world %>% filter(name != "Antarctica")

# Unir el shapefile con los datos
map_data <- world %>%
  left_join(collapsed_w_mult_mercosur_sim, by = c("iso_a3_eh" = "exporter"))

# print(colnames(map_data))
# summary(map_data)

# Crear el mapa con colores personalizados
map_plot <- ggplot(data = map_data) +
  geom_sf(aes(fill = welfare), color = "white", size = 0.2) +
  scale_fill_gradient2(
    name = "Cambio en bienestar (%)",
    low = "black",        # Color para valores negativos
    mid = "#FFF2B2",     # Amarillo claro para valores cercanos a 0
    high = "red",     # Color para valores positivos
    midpoint = 0,        # Punto medio en 0
    na.value = "gray90"  # Color para valores NA
  ) +
  theme_minimal() +
  labs(
    #  title = "World Welfare Heatmap",
    caption = "Comercio agrícola"
  ) +
  theme(
    legend.position = "bottom",
    panel.grid = element_blank()
  )

# Guardar el mapa en un archivo PDF
ggsave("world_welfare_heatmap_signed.pdf", plot = map_plot, width = 10, height = 6)


#eliminamos la columna Welfare
collapsed_w_mult_mercosur_sim <- collapsed_w_mult_mercosur_sim %>%
  select(exporter, real_wage, nom_wage, price_index )

#En porcentajes
collapsed_w_mult_mercosur_sim <- collapsed_w_mult_mercosur_sim %>%
  mutate(real_wage=(real_wage-1)*100)  %>%
  mutate(nom_wage=(nom_wage-1)*100)  %>%
  mutate(price_index=(price_index-1)*100)



colnames(collapsed_w_mult_mercosur_sim) <- c("País", "Salario Real", "Salario Nominal", "Precios","MERCOSUR", "EU")

collapsed_w_mult_mercosur_sim <-huxtable(
  collapsed_w_mult_mercosur_sim
)
number_format(collapsed_w_mult_mercosur_sim)<- "%.5g"


# Añadir título y etiqueta
caption(collapsed_w_mult_mercosur_sim) <- "Resultados: Equilibrio General (todos los países)"
label(collapsed_w_mult_mercosur_sim) <- "tab:gegravity_total"
tabular_environment(collapsed_w_mult_mercosur_sim) <-  "longtable"
writeLines(to_latex(collapsed_w_mult_mercosur_sim, tabular_only = TRUE), "collapsed_w_mult_mercosur_sim.tex")

